@@ -203,9 +203,10 @@ test('set returns proper booleans', function (t) {
 })
 
 test('drop the old items', function (t) {
+  var n = process.env.CI ? 1000 : 100
   var cache = new LRU({
     max: 5,
-    maxAge: 50
+    maxAge: n * 2
   })
 
   cache.set('a', 'A')
@@ -213,23 +214,23 @@ test('drop the old items', function (t) {
   setTimeout(function () {
     cache.set('b', 'b')
     t.equal(cache.get('a'), 'A')
-  }, 25)
+  }, n)
 
   setTimeout(function () {
     cache.set('c', 'C')
     // timed out
     t.notOk(cache.get('a'))
-  }, 60 + 25)
+  }, n * 3)
 
   setTimeout(function () {
     t.notOk(cache.get('b'))
     t.equal(cache.get('c'), 'C')
-  }, 90)
+  }, n * 4)
 
   setTimeout(function () {
     t.notOk(cache.get('c'))
     t.end()
-  }, 155)
+  }, n * 6)
 })
 
 test('manual pruning', function (t) {
@@ -300,6 +301,22 @@ test('disposal function', function (t) {
   t.end()
 })
 
+test('no dispose on set', function (t) {
+  var disposed = false
+  var cache = new LRU({
+    max: 1,
+    noDisposeOnSet: true,
+    dispose: function (k, n) {
+      disposed = n
+    }
+  })
+
+  cache.set(1, 1)
+  cache.set(1, 10)
+  t.equal(disposed, false)
+  t.end()
+})
+
 test('disposal function on too big of item', function (t) {
   var disposed = false
   var cache = new LRU({
